@@ -6,10 +6,6 @@
     if (attr(x, "type")=="factor")
         stop("function not yet implemented for factors")
 
-    ## spatstat needed
-    if (!require(spatstat))
-        stop("the package spatstat should be available for this function")
-
     ## Results
     xy<-getXYcoords(x)
     sorties<-spatstat::im(t(unclass(x)), xy$x,xy$y)
